"""
Configs migration

Generation datetime: 2025-05-20 07:14:50.455470+00:00
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "5a084756"
DOWN_REVISION = "9b3fea2c"


limitationsToModify: list[LimitationToModify] = []

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_API_CORS",
        validationSchema={
            "properties": {
                "access_control_expose_headers": {
                    "type": "array",
                    "items": {"type": "string"},
                    "description": "List of  access control expose headers",
                }
            },
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "access_control_expose_headers": [
                "X-Luna-Meta-Rescale",
                "X-Luna-Expiry-Date",
            ]
        },
        description="Luna-API CORS settings.",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_API_CORS")
