from argparse import ArgumentParser, ArgumentTypeError
from typing import Literal


def positiveInt(value):
    """Positive integer getter"""
    ivalue = int(value)
    if ivalue <= 0:
        raise ArgumentTypeError("%s is an invalid positive int value" % value)
    return ivalue


def getParsedCMDArgs(lambdaType: Literal["handlers", "tasks", "standalone", "agent"] = "handlers"):
    """Get parsed cmd args"""
    if lambdaType == "handlers":
        name = nameHelp = "handlers-lambda-unique-name"
        description = "handlers lambda application"
    elif lambdaType == "standalone":
        name = nameHelp = "standalone-lambda-unique-name"
        description = "standalone lambda application"
    elif lambdaType == "tasks":
        name = nameHelp = "tasks-lambda-unique-name"
        description = "tasks lambda application"
    elif lambdaType == "agent":
        name = nameHelp = "agent-lambda-unique-name"
        description = "agent lambda application"
    else:
        raise RuntimeError(f"Unsupported lambda type: {lambdaType}")
    parser = ArgumentParser(description=description, add_help=False)
    parser.add_argument("--name", default=name, type=str, help=nameHelp)
    parser.add_argument("--version", default=1, type=positiveInt, help="lambda version")
    if lambdaType == "handlers":
        parser.add_argument("--lambda-type", default="handlers", choices=["handlers", "standalone"], help="lambda type")
    parser.add_argument("--config", type=str, help="path to config")
    parser.add_argument(
        "--config-reload",
        "-cf",
        default=0,
        type=int,
        help="reload configuration in real time",
        const=True,
        nargs="?",
        choices=[0, 1],
    )
    parser.add_argument(
        "--luna-config",
        default=None,
        type=str,
        metavar="=",
        help="origin and api version of luna-configurator service for pulling setting from it "
        '(e.g. "http://127.0.0.1:5070/1")',
    )

    cmdArgs, _ = parser.parse_known_args()
    return cmdArgs
